# Packs

The OU Container Builder can be extended via Packs, which are pre-packaged sets of configurations
and optionally additional files, that provide additional functionality to the VCE.

All packs are configured via the top-level `packs` key in the {file}`ContainerConfig.yaml`:

:::{code-block} yaml
packs:
:::

The OU Container Builder comes with the following Packs built in:

:::{tableofcontents}
:::
